package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````"!8``#0```!4D0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````J(H`
M`*B*```%`````!````$```#,C0``S)T``,R=``!X`@``I`(```8`````$```
M`@```-2-``#4G0``U)T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,R-``#,G0``S)T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`9Q6[[8((LF`O`3DV
MXM+REXBKK"D1````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"@`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```.T!`````````````!$```!V`0``
M```````````2````%P``````````````$@```,8!`````````````!(````?
M```````````````2`````@,`````````````$@```/H!`````````````!(`
M``#2`0`````````````2````)@``````````````(`````T#````````````
M`"$````^```````````````2````1```````````````$@```$L`````````
M`````!(```##`@`````````````2````V0(`````````````$@```%(`````
M`````````!(````5`@`````````````2````60``````````````$@```)L"
M`````````````!(```!@```````````````2````:```````````````$@``
M`+P"`````````````!(```!P```````````````2````A`(`````````````
M$@```'@``````````````!(```"!```````````````@````T@(`````````
M````$@```)T``````````````!(```"B```````````````2````DP$`````
M````````%@```*("`````````````!(```!"`@`````````````2````JP``
M````````````$@```#0"`````````````!(```!1`P`````````````2````
MK0(`````````````$0````P#`````````````!$```!F`@`````````````2
M````\`(`````````````$@````X#`````````````!$```"R````````````
M```2````NP``````````````$0```(0!`````````````!(```#-````````
M```````B````W```````````````(````/(``````````````!(```"C````
M```````````2````4@(`````````````$@```/<``````````````"````"/
M`@`````````````2````$0$`````````````$@```+<!`````````````!(`
M```6`0`````````````2````=`(`````````````$@```!P!````````````
M`!(```"F`0`````````````2````*@$`````````````$@```#L!````````
M`````!(````0`@`````````````2````(0(`````````````$@```$$!````
M`````````!(```!;`@`````````````2````RP(`````````````$@```.@"
M`````````````!(```!0`0`````````````2````"P(`````````````$@``
M`%<!`````````````!(```!>`0`````````````2````"P,`````````````
M(0```&\!`````````````!(```!9!```<*`````````0`!,`_0(``$`3``#(
M`@``$@`*`.<!``"T2```!````!(`"P"3`P``P"T``+`&```2``H`:00``&0W
M```\`0``$@`*`'`#``#8'P``!````!(`"@`-!```6!````0````2``@`M@,`
M`'`T``#T`@``$@`*`!,$``!$H````````!``$P!!!```W!\``*0"```2``H`
M[@,``$2@````````$``3`($#``"8+```*`$``!(`"@"@`P``$!X``%@````2
M``H`J`,``*0I``"@````$@`*`,P#``"P10``N`$``!(`"@#A`P``@"(``#``
M```2``H`^@,``'"@````````$``3``($``!$*@``<````!(`"@!D!```<*``
M```````0`!,`-@,``"P6``!H````$@`*`"$$``"P(@``L`$``!(`"@#7`P``
M0*````0````1`!(`.@0``$2@````````$``2`/,#```(%@```````!(`"@`*
M!```)$4``(P````2``H`/P,``'0L```D````$@`*`%H#``!H'@``<`$``!(`
M"@!.!```:$<``$P!```2``H`6`0``'"@````````$``3`"T$``!@)```1`4`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`%]?
M9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M
M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C;&]S961I<@!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C
M:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I
M;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D:7(`
M<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB8U]S
M=&%R=%]M86EN`'-N<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M:&8N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R=```7````T)T``!<```"\GP``%P```,B?```7````U)\``!<`
M````H```%P```!"@```7````%*```!<````<H```%P```""@```7````)*``
M`!<````HH```%P```"R@```7````-*```!<````XH```%P```$"@```7````
MP)\``!4%``#$GP``%08``,R?```5#@``T)\``!4?``#8GP``$R,``-R?```5
M*0``X)\``!4M``#DGP``%2\``.B?```5,0``[)\``!4R``#PGP``%38``/2?
M```5.P``^)\``!4]``#\GP``%4$``-">```6`P``U)X``!8$``#8G@``%@<`
M`-R>```6"```X)X``!8)``#DG@``%@H``.B>```6"P``[)X``!8,``#PG@``
M%@T``/2>```6#@``^)X``!80``#\G@``%A$```"?```6$@``!)\``!83```(
MGP``%A0```R?```6%0``$)\``!86```4GP``%A<``!B?```6&```')\``!89
M```@GP``%AH``"2?```6&P``*)\``!8<```LGP``%AT``#"?```6'@``-)\`
M`!8@```XGP``%B$``#R?```6(@``0)\``!8D``!$GP``%B4``$B?```6)@``
M3)\``!8G``!0GP``%B@``%2?```6*P``6)\``!8L``!<GP``%BX``&"?```6
M,```9)\``!8Q``!HGP``%C(``&R?```6,P``<)\``!8T``!TGP``%C4``'B?
M```6-P``?)\``!8X``"`GP``%CD``(2?```6.@``B)\``!8\``",GP``%CX`
M`)"?```6/P``E)\``!9```"8GP``%D(``)R?```60P``H)\``!9$``"DGP``
M%D4``*B?```61@``K)\``!9'``"PGP``%D@``+2?```620``N)\``!9+```!
M0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[E4(X```#&C^((RHSB4/Z\Y0#&
MC^((RHSB2/Z\Y0#&C^((RHSB0/Z\Y0#&C^((RHSB./Z\Y0#&C^((RHSB,/Z\
MY0#&C^((RHSB*/Z\Y0#&C^((RHSB(/Z\Y0#&C^((RHSB&/Z\Y0#&C^((RHSB
M$/Z\Y0#&C^((RHSB"/Z\Y0#&C^((RHSB`/Z\Y0#&C^((RHSB^/V\Y0#&C^((
MRHSB\/V\Y0#&C^((RHSBZ/V\Y0#&C^((RHSBX/V\Y0#&C^((RHSBV/V\Y0#&
MC^((RHSBT/V\Y0#&C^((RHSBR/V\Y0#&C^((RHSBP/V\Y0#&C^((RHSBN/V\
MY0#&C^((RHSBL/V\Y0#&C^((RHSBJ/V\Y0#&C^((RHSBH/V\Y0#&C^((RHSB
MF/V\Y0#&C^((RHSBD/V\Y0#&C^((RHSBB/V\Y0#&C^((RHSB@/V\Y0#&C^((
MRHSB>/V\Y0#&C^((RHSB</V\Y0#&C^((RHSB:/V\Y0#&C^((RHSB8/V\Y0#&
MC^((RHSB6/V\Y0#&C^((RHSB4/V\Y0#&C^((RHSB2/V\Y0#&C^((RHSB0/V\
MY0#&C^((RHSB./V\Y0#&C^((RHSB,/V\Y0#&C^((RHSB*/V\Y0#&C^((RHSB
M(/V\Y0#&C^((RHSB&/V\Y0#&C^((RHSB$/V\Y0#&C^((RHSB"/V\Y0#&C^((
MRHSB`/V\Y0#&C^((RHSB^/R\Y0#&C^((RHSB\/R\Y0#&C^((RHSBZ/R\Y0#&
MC^((RHSBX/R\Y0#&C^((RHSBV/R\Y0#&C^((RHSBT/R\Y0#&C^((RHSBR/R\
MY0#&C^((RHSBP/R\Y0#&C^((RHSBN/R\Y0#&C^((RHSBL/R\Y0#&C^((RHSB
MJ/R\Y0#&C^((RHSBH/R\Y0#&C^((RHSBF/R\Y0#&C^((RHSBD/R\Y0#&C^((
MRHSBB/R\Y0#&C^((RHSB@/R\Y0`````!RJ#C<$`MZ0S`3>#(#XSE6,*?Y2C0
M3>)4,I_E'`"-Y1@0C>44((WE#,"/X`,PG.<8$(WB%""-XAP`C>(T4I_E`#"3
MY20PC>4`,*#CI?__ZR0BG^4%4(_@`B"5YQPRG^4,((WE`S"5YP(0H.$#`*#A
M$#"-Y5G__^L$,I_E`S"5YP!`T^4``%3C3P``"G`O'>[P,9_E'`"=Y0,PG^<#
M0(#B`R"2YP0`@.+^,]+E!P%PXP,P@^/^,\+E8```B@`!H.&:___K`#"@X;PA
MG^48$)WE`B"/X`!@DN6PP9_EL%&?Y;#AG^4<()WE``"1Y0S`C^`%4(_@#N"/
MX`$`4N-A0(/H!#",Y50``-H$`$'B#,"#X@(!@.`$X+'E`0!0X03@K.7[__\:
M`\""X@#@H.-H49_E:!&?Y050C^`,`)7E#.&#YP0@H.$!$(_@`."-Y3[__^L`
M`%#C*0``"D11G^4@8(WB!5"/X`P`E>55___K`$"@X3`!G^4&$*#A``"/X-4`
M`.L``%#C(```"APQG^4#,(_@#`"3Y8S__^OL_O_K#"&?Y<PPG^4"((_@`S"2
MYP`@D^4D,)WE`B`SX``PH.,J```:!`"@X2C0C>)P@+WH+?__Z]P@G^4``%#C
M`B"/X`P`@N4?```*5___ZW`O'>[$,)_E`S"?YP,PDN?.1L/EH___Z@P`E>5&
M___KTO__Z@@`E>4``%#C`0``"H$(`.O9___JE`"?Y080H.$``(_@J0``ZP``
M4.,(`(7ETO__"O7__^IX,)_E>`"?Y0,PE><``(_@`Q"@X0PPC>7._O_K!,"@
MX[#__^H!`*#C)___ZUS__^M4BP``(`$``"B+```X`0``-`$````!``#XBP``
M*(P``"R,```H.```*#@``.2+``#8"```N(L``$0U``",BP``V(D``$"+``"@
MB@``,#0``!@!```,-@```+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0``
M`.NXAP``!.`MY0#@H.,`(*#A1!"?Y40`G^4!$(_@``"1YQ303>(X,)_E"`"-
MY0,PD><PP)_E##"-Y03@C>4,$)'G`#"@X0`0C>4,`)WE!!"2Y.3^_^L4T(WB
M!/"=Y'R(```0`0``^`````0!```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#
M,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_AH(D``)R)```0B```#`$``#@`
MG^4X,)_E``"/X`,PC^``,$/@HQ^@X4,1@>`D,)_EP1"PX0,PC^`>_R\!&""?
MY0(PD^<``%/C'O\O`1/_+^%<B0``6(D``,"'```L`0```<J@XQ!`+>D,P$W@
M^`^,Y60PG^5D0)_E`S"/X``PT^4$0(_@``!3XQ"`O1A0,)_E`S"4YP``4^,"
M```*1#"?Y0,`G^>P_O_KQ___ZS@PG^4#,)3G``!3XP(```HL`)_E``"/X%3^
M_^L!(*#C(#"?Y0,PC^``(,/E$("]Z/R(``!TAP``)`$``)"(```(`0``%',`
M`*2(``!`,)_E0""?Y0,PC^`",)/G``!3XPH```H!RJ#C$$`MZ0S`3>#X#XSE
M(!"?Y2``G^4!$(_@``"/X)#^_^L00+WHM/__ZK/__^KTA@``*`$``%"(``"H
M<@```<J@X_!'+>D,P$W@X`^,Y;PPG^6\()_E`S"/X`(PD^<`D)/E``!9XR<`
M``H`4-#E`("@X0``5>,]`%43`7"@X0%0H!,`4*`#$0``&@!`F>4``%3C#```
M"@E@H.$%(*#A"!"@X00`H.$X_O_K``!0XP(``!H%,-3G/0!3XPL```H$0+;E
M``!4X_/__QH$`*#A\(>]Z`!0H.$!,/7E``!3XST`4Q/[__\:"%!%X.;__^H)
M8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"4"@X>W__^J,A@``'`$```'*
MH.,00"WI#,!-X%@/C.6,()_EC#"?Y0(@C^"@T$WB`S"2YPT0H.$`,)/EG#"-
MY0`PH.,`0*#A9_[_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,*```*
M2""?Y4`PG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.,'```:H-"-XA"`O>@"
M$*#C!`"@X<K]_^L0#V_AH`*@X>[__^IB_O_KL(4``"`!``!DA0```<J@X_!`
M+>D,P$W@2`^,Y50AG^54,9_E`B"/X`,PDN>DT$WB`%!0X@`PD^6<,(WE`#"@
MXP(```H`,-7E``!3XPH``!HH(9_E(#&?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@
M`#"@XS\``!JDT(WB\("]Z)?]_^L`0%#B\?__"@0`H.&Z_?_K``!0XR@```H3
M,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`4^,C```*!0"@X2W^
M_^L`<*#A!@"@X2K^_^L``(?@`@"`XK7]_^L&,*#A`&"@X900G^4%(*#A`1"/
MX!C^_^L&`*#A#1"@X0#^_^L!`'#C!@"@X0,```H0,)WE#SH#X@$)4^,2```*
MH?W_ZP8`H.'__?_K!`"@X9']_^L``%#CUO__&@0`H.&N_?_K!0"@X>O]_^N_
M___J`3#6Y2X`4^/8__\:`C#6Y0``4^/'__\*U/__ZJ;__^OK___J!/[_ZP"%
M```@`0``S(0``,`N```!RJ#C\$<MZ0S`3>#8#XSE`4"@X1`BG^40,I_E`B"/
MX`,PDN<(T$WB`#"3Y00PC>4`,*#C`##1Y0!0H.$]`%/C`4"!`@0`H.'J_?_K
M#1"@X0!@H.$%`*#A)O__Z]!QG^4`D%#B!W"/X$````KA_?_K``!6X3<``)JX
M,9_E`("=Y0-PE^<(@:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@
M\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)?E6?W_ZP``4.,(`(;G%0``
M"@4`H.$`,)?E"!"3YP$PT.0]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"$*#A
M``!3XST`4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0``%/C`3#BY?O__QH(
M(9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&0
M2>(!,-3D``!3XP$PZ>7[__\:[O__ZL`PG^4#<)?G`("7Y0`PF.4``%/C)```
M"@@PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``()/E
M``!2XP\``!H!(*#C`0"@X0`@@^48_?_K`*!0XM7__PH($*#A"8&@X0@@H.$5
M_?_K`*"'Y0`PH.,`D(WE`9")X@DQBN>B___J"`"@X=W\_^L``%#C`*"@X0``
MA^7%__\*"8&@X?+__^H#D*#A"!"@X]___^IU_?_K@(,``"`!```X@P``'`$`
M`&B"``",@P```<J@XQ!`+>D,P$W@Z`^,Y7!/'>YL$)_E;#"?Y0$0C^`#,)'G
M$-!-XF``G^4,,(WE`R"@X0``G^=4,)_E5!"?Y0``E.<#,(_@`1"/X$G]_^L`
MP*#C0`"?Y4`PG^4``)_G/""?Y3P0G^4#,(_@``"4YP(@C^`($(WH`1"/X+G\
M_^L0T(WB$("]Z#R!```P`0``.((``%!L``"D*P``$((``(@N``"4%@``D"L`
M`#P0G^4\,)_E`1"/X`,PD>=PSQWN`R"@X0C03>(H`)_E!#"-Y0``G^<@,)_E
M(!"?Y0``G.<#,(_@`1"/X`C0C>(A_?_JI(```#`!``"<@0``M&L```@K```!
MRJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SE-"&?Y0+:3>(P,9_E&-!-X@(@
MC^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..1_/_K#,&?Y0Q!G^4,(9_E#,"/
MX`Q@C>(`,*#A!!"@X08`H.$"((_@`,"-Y7?\_^L!,(#B!`!3X3```(H!`'#C
M+P``"@%:C>(04(7B`2J@XP40H.$&`*#AP_S_ZP!`4.(G``"Z`0"$XHS\_^L`
M,%#B(P``"@4`4^$"```J!""#X`(`5>$=```Z!0!3X1@``(J$()_E`@!4X1@`
M`(H$(*#A`P"@X040H.'H_/_K`""@XP`PH.$$(,#G9!"?Y5`@G^4!$(_@`@J-
MX@(@D><4`(#B`!"2Y0`@D.4!$#+@`""@XPD``!H#`*#A`MJ-XAC0C>)P@+WH
M!""%X`(`4^'C__\J\`#PYP`PH./J___JV/S_ZRB````@`0``T"H```$0``"P
M*@``3'\``*+__^H!RJ#C\$\MZ0S`3>```(SET``,Y5C"G^5"W4WB5"*?Y2S0
M3>(,P(_@`%"@X4@"G^4"()SG0CV-X@APC>(!8*#A``"/X`<0H.$D,(/B`""2
MY0`@@^4`(*#C]_W_ZR\0H.,`0*#A!0"@X67\_^L``%#C$@``"@0"G^4%$*#A
M``"/X*_^_^L%`*#A]"&?Y>0QG^4"((_@0AV-X@,PDN<D$('B`""3Y0`PD>4"
M(#/@`#"@XVT``!I"W8WB+-"-XO"/O>@&`*#A/_S_Z[@1G^4!$(_@C?S_ZP"@
M4.+E__\*`##:Y:2!G^6HD(WB``!3XPB`C^`$8$GB/P``"@``5.,$```*"A"@
MX00`H.$'_/_K``!0XR\```H*`*#AA_S_ZP$P0.(#,(K@`P!:X0`@H.$`L*#A
M`!"@,P`@BC`!,(HR`P``.@@``.H"`%/A`!#"Y0(```H!P'+E+P!<X_G__PH*
M`*#A=?S_ZP"PH.$%`*#A<OS_ZPL`@.`!`(#B`0I0X[S__RH(P9_E"C"@X0S`
MC^`((*#A`1J@XP8`H.$$4(WE`,"-Y<_[_^L!`(#B`0I0XR\``(H'$*#A!@"@
MX4'\_^L``%#C`P``&I`P&>4/.@/B`@E3XQ4```JX$)_E``"@XP$0C^!)_/_K
M`*!0XJ'__PH`,-KE``!3X[___QH``%3C%@``"@`PU.4N`%/C`P``"H2@G^4!
ML*#C"J"/X-+__^H!,-3E``!3X^K__PKW___J`1"@XP8`H.&G^__K``!0X^3_
M_QI4`)_E!A"@X0``C^`\_O_K!@"@X=O[_^N*___J/*"?Y0&PH.,*H(_@OO__
MZC7\_^OP`/#GO'X``"`!``!\*0``3"D``%!^```,*0``\"@``%PH``#\)P``
MI"<``(`G``!4)P```<J@XQ!`+>D,P$W@^`^,Y2\0H.,`0*#AN/O_ZP``4.,!
M0(`2!`"@X1!`O>B\^__J`<J@XS!`+>D,P$W@``",Y1@`#.5X(9_E`=I-XG0Q
MG^4,T$WB`B"/X`$:C>(#,)+G`%!0X@00@>(`,)/E`#"!Y0`PH.,P```*`##5
MY0``4^,M```*`_S_ZP$`@.(!"E#C.@``B@1`C>(%$*#A!`"@X9/[_^L$`*#A
M^OO_ZP$`0.(``(3@!`!0X0<``)H`(*#C`@``Z@``5.$!(,#E`@``"@$P4.0O
M`%/C^?__"B\0H.,$`*#AA?O_ZP``4.,E```*!`!0X0`PH(,`,,"%!`"@X8?[
M_^O`()_EN#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C(P``
M&@':C>(,T(WB,("]Z(P@G^6`,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E
M`B`SX``PH.,5```:9`"?Y0``C^`!VHWB#-"-XC!`O>AH^__J``"@X][__^I(
M()_E-#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C`@``&B``
MG^4``(_@Z___ZK?[_^OH>P``(`$``#![``#X>@``J"4``*QZ``!<)0```<J@
MXW!`+>D,P$W@Z`^,Y<0DG^7$-)_E`B"/X,!4G^4#,)+GO&2?Y0C03>(%4(_@
M`#"3Y00PC>4`,*#C!F"/X`U`H.$$$*#A!@"@X=G\_^L``%#C#@``"HPTG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___ZE1DG^4&8(_@!!"@X08`H.'#_/_K``!0XPX```HT-)_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^H`9)_E!F"/X`00H.$&`*#AK?S_ZP``4.,.```*W#.?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___JK&.?Y09@C^`$$*#A!@"@X9?\_^L``%#C#@``"H0SG^4`$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___ZEACG^4&8(_@!!"@X08`H.&!_/_K``!0XPX```HL,Y_E`!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^H$8Y_E!F"/X`00H.$&`*#A:_S_ZP``4.,.```*U#*?Y0`0G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
ML&*?Y09@C^`$$*#A!@"@X57\_^L``%#C#@``"GPRG^4`$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZEQB
MG^4&8(_@!!"@X08`H.$__/_K``!0XPX```HD,I_E`!"=Y0,PE><`()/E`3&"
MX`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H(8I_E
M!F"/X`00H.$&`*#A*?S_ZP``4.,.```*S#&?Y0`0G>4#,)7G`""3Y0$Q@N`$
M`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JM&&?Y09@
MC^`$$*#A!@"@X1/\_^L``%#C#@``"G0QG^4`$)WE`S"5YP`@D^4!,8+@!`"3
MY0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZF!AG^4&8(_@
M!!"@X08`H.']^__K``!0XPX```H<,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4`
M`%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H,`9_E!!"@X0``
MC^#H^__K`!!0X@(```KX`)_E``"/X*7\_^OP`)_E!!"@X0``C^#?^__K`!!0
MX@(```K<`)_E``"/X)S\_^O4`)_E!!"@X0``C^#6^__K`!!0XA(```K``)_E
M``"/X)/\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8
M$)_EF`"?Y0$0C^```(_@"-"-XG!`O>B#_/_JA`"?Y000H.$``(_@O?O_ZP`0
M4.+I__\*<`"?Y0``C^!Z_/_KY?__ZGGZ_^M$>@``(`$``#!Z```H)0``'`$`
M`-@D``"()```/"0``.PC``"D(P``Z"(````C``"T(@``:"(``)0A``#`(0``
ME"$``+`A``"P(0``K"$``-`@``#D=0``B"$``.P@``!8(0``W"````'*H.,$
MX"WE#,!-X/`/C.5X()_E>#"?Y0(@C^!T`)_E#-!-X@,PDN<-$*#A``"/X``P
MD^4$,(WE`#"@XXS[_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@
MXC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WD
M._K_ZP!U```@`0``."```+!T```!RJ#C#P`MZ03@+>4,P$W@\`^,Y40@G^5$
M,)_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C+#"?Y2P`G^44((WB`S"/X``@
MC>4`,)/G$!"=Y0``D^7'^?_K_P"@X^GY_^M<=```(`$``#AT``#\`````,"@
MX_!#+>D!Z*#C#,!-X`[@3.`!RDSB``",Y0X`7.'[__\:.``.Y0(0H.-PX9_E
M`=A-XFS!G^4<T$WB#N"/X`S`GN<!2(WB`""@XP`PH.,`P)SE%,"$Y0#`H.,`
M$(WE`("@X73Y_^L!8%#B`'#!XL<OH.''/R;@`C!3X',P_^8","/@`C!3X`(@
MPN`#8%;@`G#'X```5^,40(3B-@``N@Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-
MY5_Y_^L!`''C`0!P`S(```H%$*#A"`"@X=0@G^6[^?_K`0!PXRD```H'`%#C
M'P``F@@`0.(`0)7@'```*K20G^4)D(_@`@``Z@%`1.(%`%3A%@``.@@@H.,)
M$*#A!`"@X2SY_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(
MC>(#,)+G%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAS0C>+P@[WH`6A6
MX@!PQ^(!`'?C`0AV`\G__QH``.#C`!"@X>G__^HH`)_E``"/X'[__^L@`)_E
M``"/X'O__^NR^?_KS',``"`!```(``$`4'0``-!R``!8'@``/!X```'*H.,0
M0"WI#,!-X/@/C.6I^?_K6OG_ZP``4.,``)`5$("]Z`'*H./P0"WI#,!-X-@/
MC.7P()_E\&"?Y?`PG^4"((_@%-!-X@,PDN<&8(_@`%"@X08`H.$($(WB`#"3
MY0PPC>4`,*#CS?K_ZP!`4.("```*`##4Y0``4^,.```:L""?Y:@PG^4"((_@
M`S"2YP`@D^4,,)WE`B`SX``PH.,@```:!1"@X8P`G^4``(_@%-"-XO!`O>A[
M^__J!0"@X7?Y_^L`<*#A!`"@X73Y_^L``(?@`@"`XO_X_^M<,)_E7!"?Y04@
MH.$#,(_@`1"/X`!`C>4`0*#A8/G_ZT0@G^4L,)_E`B"/X`,PDN<`()/E##"=
MY0(@,^``,*#C!!"@`08`H`'A__\*8/G_ZPAR``#D'0``(`$``,!Q``"$'0``
M6!P``%@<``!$<0```<J@X_!/+>D,P$W@P`Z,Y4??3>+(H(WB"N"@X0`6G^4`
MQI_E`":?Y0$0C^`"()'G#,"/X`PPC.(8D(SBL%"-X@`@DN44(8WE`""@XP!P
MH.$'`)/H!P"%Z`\`N>@/`*[H`P"9Z##`C.*\0(WB`P".Z`<`G.@'`(3HL`6?
MY1A@C>(&$*#A``"/X'+Z_^N@A9_E`)!0X@B`C^`"```*`##9Y0``4^,)`0`:
M,/G_Z^'X_^L``%#C<@``"@"0D.4``%GC;P``"@D`H.$B^?_K@`"@X0$`@.*M
M^/_K`"#9Y0!`H.$``%+C%`"-Y0@```I$M9_E"["/X`0`H.$+$*#A#/G_ZP$@
M^>4"0(3B``!2X_C__QHD!9_E``"/X`(``.H$`+KE``!0XPT```H&$*#A2?K_
MZP!`4.+X__\*`##4Y0``4^/U__\*>OK_ZP``4./R__\*!`"@X:+X_^L`0%#B
M#```&@1`E>0``%3C"0``"@`PU.4``%/CQ0``"@0`H.%L^O_K``!0X_'__QH$
M0)7D``!4X_7__QH$`*#A[OC_ZQ20G>4`4*#A"0"@X>KX_^L`4(7@`5N%X@10
MA>(%`*#A<_C_ZP20C>4`D*#A<#2?Y7`4G^4#,(_@`#"-Y6@TG^4$(*#A`S"/
MX`$0C^#1^/_K!QV@XPD`H.&_^/_K`0!PXP,``!JY^/_K`,"0Y1$`7..E```:
M!A"@X0D`H.&\^/_K`$!0XBP```H@))_E(!2?Y0(`F.<),*#A`""7Y0``D.4!
M$(_@E/C_ZP!0H.,$))_EV#.?Y0(@C^`#,)+G`""3Y10QG>4"(#/@`#"@X^D`
M`!H%`*#A1]^-XO"/O>A9^/_K`)!0XH0``!H$`)3D``!0XPD```H&$*#A[_G_
MZP`P4.+X__\*`##3Y0``4^/R__\:!`"4Y```4./U__\:#0"@XS/X_^N0DY_E
M4R"@XP!`H.$)D(_@%`"-Y83__^HH,)WE#SH#X@$)4^/.__\:,*"=Y9_X_^L`
M`%KARO__&B@PG>6#.Z#AHSN@X0<-4^/%__\:!0"@X1[X_^L`4*#A/`.?Y080
MH.$``(_@R_G_ZP`04.)U```*``"7Y;C[_^L`H%#B<0``"@H`H.&#^/_K`P!0
MXP"`H.$,``":!!.?Y00`0.(``(K@`1"/X/?W_^L``%#C!0``&@0`6..7```*
M"("*X`4P6.4O`%/CDP``"M0"G^4&$*#A``"/X*_Y_^L``%#C`P``"@`PT.4P
M`%/C``!3$P0``!H`$*#C"@"@X0SX_^L`8%#B4@``&IP2G^6<`I_E`1"/X```
MC^!A^O_KU_?_ZXPBG^6,,I_EC!*?Y0(@C^"(@I_EB'*?Y8ABG^4%`(WH`S"/
MX`D@H.$%`*#A`1"/X$CX_^L(@(_@!W"/X`9@C^`-``#J,?C_ZP`PD.41`%/C
M#@``&L'W_^L`P*#A`4"$X@@PH.$)(*#A!Q"@X04`H.%0`(WI`,"-Y3;X_^L'
M':#C!0"@X23X_^L!`'#C[/__"@D`H.$C^/_K#`*?Y040H.$``(_@-OK_ZP4`
MH.&2_O_K;?__Z@-`H.$^___J+OC_ZX``H.$!`(#B"O__ZIPAG^78$9_E`@"8
MYPDPH.$`()?E`1"/X`#`C>4``)#E\O?_ZUS__^J`_O_KM"&?Y4PQG^4"((_@
M`S"2YP`@D^44,9WE`B`SX``PH.-&```:"0"@X4??C>+P3[WHMO?_Z@"@E^6+
M___J]_W_ZP"`4>(`<*#AJ/__N@"@H.,*(%#B`##(X@8`H.$`H(WEX+"-XGSW
M_^L&(*#C"Q"@X08`H.';]__K!@!0XS```!HX,9_EX""=Y0,`4N&7__\:M"#;
MX2@QG^4#`%+AD___&C(@5^(`,,CB!@"@X0"@C>7H0(WB:/?_ZR@@H.,&`*#A
M!!"@X<?W_^LH`%#C'```&O`@G^7P,)_E\!"?Y0(@C^`$((WE!0"@X0D@H.$`
M0(WE`S"/X`$0C^`0H<WEU_?_ZZ3__^H$<)?E``!7XVC__PH'`*#AVO?_ZP,`
M4.-D__^:K!"?Y00`0.(``(?@`1"/X$_W_^L``%#C!Z"@`5S__^K2]__KC`"?
MY0``C^"7_?_KU'````QR```@`0``5!L``&AP```,'```@!L``$`;```@&P``
M(!H``/P````8&P``K&X``"@:``"(&@``4!H``+@8``#X&```>!@``*P:```$
M&```U!D``/`7``#8&0``?!H``%P7``!<&```(&P```!#04-(10``Y!@``#P6
M```$&```N!<``*07```!RJ#C<$`MZ0S`3>#H#XSE>"*?Y7@RG^4"((_@`S"2
MYPC03>(`,)/E!#"-Y0`PH.-P3QWN7#*?Y5P"G^4#,)_G#1"@X0-0E.<``(_@
M:##5Y0U@H.%I,,7ETOC_ZP``4.,"```*`##0Y3$`4^-B```*WOO_ZR0RG^4#
M,)_G`U"4YQP2G^4%`*#A`S"@XP$@H.,!$(_@,O?_ZP!04.(,```*$""5Y?PQ
MG^4`$)+E`S"?Y_0AG^4#`)3G`B"/X"[W_^L0,)7E`!"3Y0@PD>4!!1/C6@``
M&M01G^4#,*#C`1"?YP$@H.,!`)3GQ!&?Y0$0C^`;]__K`%!0X@L```JT`9_E
M!A"@X0``C^"F^/_K`"!0XCT```J@,9_E$!"5Y0,PG^<`$)'E`P"4YQ/W_^N,
M,9_EC!&?Y0,PG^<!(*#C`U"4YP$0C^`%`*#ANO;_ZW0AG^4`$*#A`B"/X`4`
MH.$&]__K`""@XV`QG^5@`9_E`S"?YP80H.$#,)3G``"/X&D@P^6(^/_K2$&?
MY0``4.,$0(_@"`"$Y1````H'':#C*??_ZP$P@.(1`%#C`0!3$R\``(H@(9_E
MV#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XR4``!H(T(WB<("]Z`0`E.7:
M_?_K``!0XP@`A.7I__\:Y`"?Y0``C^":]O_K`3#0Y0``4^.=__\*F/__ZOGY
M_^O(,)_E$""5Y0,PG^<`4%#B`!"2Y0,`E.<)```*!2"@X='V_^L%`*#A!??_
MZ[K__^J<,)_E`S"?YP,`E.>=]O_KG___ZHPPG^4#,(_@!#"3Y0`@D^7$]O_K
MK___ZA#W_^MT()_E`#"@X7``G^4"((_@!@"2Z0``C^``$)'E=?;_ZS1J```@
M`0``)&L``#05``#H:@``P!8``+1J``"<%@``A&H``'`6```P%```1&H``"QJ
M```@%@``)!8``/1I``"P$P``7&H``)1H``",%0``2&D``!QI``"0:0``;&D`
M`"`5```!RJ#C,$`MZ0S`3>#H#XSE#"&?Y0PQG^4"((_@`$"@X00!G^4#,)+G
M#-!-X@T0H.$``(_@`#"3Y00PC>4`,*#C&_C_ZP`P4.(*```*`##3Y3``4^,`
M`%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!,`,2``!3XPH``!JP()_EI#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XR```!H,T(WB,("]Z``PU.4``%/C\?__
M"@0`H.&D^O_K+Q"@XP!0H.%5]O_K``!0XP%0@!(%`*#A6O;_ZU@0G^4$(*#C
M`1"/X$?V_^L``%#CXO__&D0@G^4P,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C`P``&@0`H.$,T(WB,$"]Z$?X_^JF]O_K0&<``"`!``!T$@``V&8``)`2
M``!D9@```<J@X_!/+>D,P$W@0`V,Y5`LG^50/)_E`B"/X`,PDN>GWTWB`!"@
MX1#`C>(`,)/EE#*-Y0`PH.,,(*#A`$"@XT``@.*`4('B0$`0Z2XTH.'_/`/B
M+CR#X0YTH.$./(/A_W@'X@@`@.(V[[_F!S"#X0``5>$`X(+E!$""Y0@P@N4,
M0(+E$"""XN[__QJ"/XSB'$"=Y7C`G>4$,(WEB#"=Y1A0C>(($(WE!0"@X0RP
MH.$#$*#A?""=Y1B@G>6`@)WEA'"=Y8S@G>408)WE%)"=Y0!`C>4,4(WE`0``
MZ@6@H.$`0(WE`$"@XP$PH.$\P)#E.!"0Y0A0L.5T0(#E!$"0Y040(>`+$"'@
M!,`LX`80(>`"P"S@"<`LX`BPH.$#@*#AH3^@X8PP@^$!$)'@`Q"!X00PG>4'
M(*#A`P!0X0YPH.$*8*#A`."@XP"0G>5P$(#EX?__&@@0G>4,4)WE`)"1Y0@[
MG^4((!7E(."1Y:EMH.$!")'I$("1Y1B@D>4#()+@@&*&X0X@DN")8H;A#,"1
MY0)@EN`*("C@*T&@X0L@`N`*("+@#$^$X0)@EN`+3X3A&""=Y2G!H.$`SXSA
M!``HX`,@DN`)``#@"B"2X`@`(.`)SXSA``"2X`@@E>4,X"3@`R"2X`;@#N`$
MX"[@"""2X.8-@.`.()+@X.V"X!`@E>4#()+@!""2X&9!+.``0`3@#$`DX`0@
MDN`80)7E8`&@X0-`E.`,P)3@9D$@X`Y`!.!F023@[BV"X`3`G.#B38S@(,"5
MY0/`G.!FP8S@;F$@X`)@!N``8";@!L"<X"A@E>5B(:#A`V"6X```EN!N82+@
M!&`&X&YA)N#DS8S@!@"0X.QM@.`P`)7E`P"0X&X!@.!DX2+@#.`.X`+@+N`.
M`)#@.."5Y6S!H.$#X)[@`B">X&3A+.`&X`[@9.$NX.8-@.`.()+@X.V"X$`@
ME>4#()+@9"&"X&9!+.``0`3@#$`DX`0@DN!(0)7E8`&@X0-`E.`,P)3@9D$@
MX`Y`!.!F023@[BV"X`3`G.#B38S@4,"5Y0/`G.!FP8S@;F$@X`)@!N``8";@
M!L"<X%A@E>5B(:#A`V"6X```EN!N82+@!&`&X&YA)N#DS8S@!@"0X.QM@.!@
M`)7E`P"0X&X!@.!DX2+@#.`.X`+@+N`.`)#@:."5Y6S!H.$#X)[@`B">X&3A
M+.`&X`[@9.$NX.8-@.`.()+@X.V"X'`@E>4#()+@9"&"X&9!+.``0`3@#$`D
MX`0@DN!X0)7E8`&@X0-`E.`,P)3@9D$@X`Y`!.!F023@[BV"X`3`G.#B38S@
M@,"5Y0/`G.!FP8S@;F$@X`)@!N``8";@!L"<X.1MC."(P)7E8B&@X0/`G.``
M`)S@;L$BX`3`#.!NP2S@#`"0X.;-@."0`)7E`S"0X&0!(N`&``#@`@`@X&XQ
M@^``,)/@['V#X)@`E>4L.)_E9F&@X0,`D."@X)7E`B"0X&0!)N`,`"#@`""2
MX`,`GN!D`8#@Y^V"X*A`E>5L(2;@!R`BX`(`D.!G(:#A`T"4X+!PE>4&0)3@
M;&$BX`Y@)N#N#8#@!D"4X`-@E^!L88;@N'"5Y>#-A.!N02+@`$`DX`1@EN!@
M`:#A`T"7X`)`E.#`<)7E["V&X&YA(.`,8";@!F"4X`-`E^!N083@R'"5Y6SA
M(.`"X"[@XFV&X`Y`E.!B(:#A`^"7X```GN#0<)7E;.$BX`;@+N`.X)#@`P"7
MX.9-A.#8<)7E;`&`X&;!(N`$P"S@Y.V.X`P`D.!D0:#A`\"7X`(@G.#@<)7E
M9L$DX`[`+.`,P)+@`R"7X.X-@.#H<)7E9B&"X&YA).``8";@X,V,X`8@DN!@
M`:#A`V"7X`1@EN#P<)7E;D$@X`Q`).`$0);@`V"7X.PM@N!N88;@^%"5Y6SA
M(.`"X"[@XDV$X`[@EN!B(:#A`U"5X`!0E>`889WE;`$BX`0`(.#D[8[@``"5
MX`-@EN#N78#@;,&&X&0!(N`@89WE#@`@X&[AH.$H<9WE``"<X`-@EN!DP2[@
M`B"6X`7`+.#E#8#@#,"2X`,@E^#@;8S@9"&"X&7!+N`P09WE`,`LX`S`DN!@
M`:#A`T"4X.8MC.`.X)3@9<$@X#A!G>4&P"S@#,">X`/@E.!EX8[@9D$@X$!1
MG>4"0"3@XLV,X`3@GN!B(:#A`U"5X```E>!F02+@2%&=Y0Q`).`$0)#@`P"5
MX.SMCN#P-9_E4'&=Y68!@.!L82+@;E&@X0Y@)N#N383@!F"0X&SAA>$#`)?@
M`@"0X%AQG>7D+8;@!.`.X&QA!>`&X([A#N"0X`-PE^!D`87A9&$%X&S!A^`"
M``#@8'&=Y08`@.'B[8[@#`"0X&(AH.$#P)?@!<"<X&11@N%D80+@:'&=Y0Y0
M!>`&4(7A[@V`X`Q0E>`#<)?@;L&"X6YA`N!D08?@`,`,X'!QG>4&P(SAX%V%
MX`1`G.!@`:#A`\"7X`+`G.#E+83@;D&`X6YA`.!X<9WE!4`$X`9`A.$,0)3@
M`W"7X&7!@.%E80#@;N&'X`+`#."`<9WE!L",X>)-A.`.X)S@8B&@X0/`E^``
MP)S@Y`V.X&7A@N%E80+@B'&=Y03@#N`&X([A#.">X`-PE^!DP8+A9&$"X&51
MA^``P`S@D'&=Y0;`C.'@[8[@!5"<X&`!H.$#P)?@`L"<X.XMA>!D48#A9&$`
MX)AQG>4.4`7@!E"%X0Q0E>`#<)?@;L&`X6YA`.!D08?@`L`,X*!QG>4&P(SA
MXEV%X`1`G.!B(:#A`\"7X`#`G.#E#83@;D&"X6YA`N"H<9WE!4`$X`9`A.$,
M0)3@`W"7X&7!@N%E80+@;N&'X`#`#."P<9WE!L",X>!-A.`.X)S@8`&@X0/`
ME^`"P)S@Y"V.X&7A@.%E80#@N'&=Y03@#N`&X([A#.">X`-PE^!DP8#A9&$`
MX&51A^`"P`S@P'&=Y0;`C.'B[8[@!5"<X&(AH.$#P)?@`,"<X.X-A>!D48+A
M9&$"X`Y0!>`&4(7A#%"5X&[!@N%N80+@`,`,X`;`C.$`8*#CR'&=Y>!=A>`#
M<)?@9$&'X-!QG>5@`:#A!$"<X`/`E^`"P)S@Y2V$X&Y!@.$%0`3@!&"!Y0Q@
M@>448('E'&"!Y6YA`.#8<9WE!D"$X0Q`E.!EP8#A`W"7X&5A`.`"P`S@;N&'
MX`;`C.'@<9WEXDV$X`[`G.!B(:#AY.V,X`-PE^!EP8+A96$"X```E^`$P`S@
MZ'&=Y0;`C.$`P)S@`W"7X&0!@N'H,I_E9&$"X&51A^`.``#@\'&=Y08`@.'N
MS8S@!0"0X&[AH.$#4)?@`E"5X/AAG>5D(2[@#"`BX.P-@.`"()7@`V"6X.!=
M@N!D08;@;"$NX`!BG>4`("+@`B"4X&`!H.$#0);@#D"4X`ABG>5LX2#@!>`N
MX`[@E.`#0);@Y2V"X!!BG>5L083@9<$@X`+`+.#B[8[@#,"4X&(AH.$#0);@
M`$"4X!ABG>5E`2+@#@`@X.[-C.```)3@`T"6X&5!A.`@8IWE[%V`X&X!(N`,
M`"#@``"4X&S!H.$#0);@`D"4X"ABG>5N(2S@!2`BX.4-@.`"()3@`V"6X.!-
M@N!NX8;@92$LX#!BG>4`("+@`B">X&`!H.$#X);@#.">X#ABG>5EP2#@!,`L
MX.0M@N`,P)[@`^"6X&7ACN!`8IWEXEV,X&3!(.`"P"S@#,">X&(AH.$#X);@
M`.">X$ABG>5D`2+@!0`@X.7-C.```)[@`^"6X&3ACN!08IWE[$V`X&4!(N`,
M`"#@``">X&S!H.$#X);@`N">X%ABG>5E(2S@!"`BX.0-@.`"()[@`^"6X&7A
MCN!@8IWEX%V"X&0A+.``("+@`B">X&`!H.$#X);@#.">X&ABG>5DP2#@!<`L
MX.4M@N`,P)[@`^"6X&3ACN!P8IWEXDV,X&7!(.`"P"S@#,">X&(AH.$#X);@
M`.">X'ABG>5E`2+@!``@X```GN`#X);@Y,V,X&7ACN!D82+@@%*=Y>P-@.`,
M8";@;,&@X0;@GN`#4)7@9&$LX`!@)N`"()7@!B"2X`!@H..(4IWEX.V.X`,P
ME>!@H8K@"3"3X&`!+.`.`"#@9#&#X``PD^#N+8+@XCV#X"``D>4+()+@;H&(
MX!B@@>40@('E`#"!Y0@@@>5,()_E`,"<X#`PG^4"((_@(,"!Y21@@>4#,)+G
M`""3Y90RG>4"(#/@`#"@XP$``!JGWXWB\(^]Z(;S_^L$9@``(`$``)EY@EJA
MZ]ENW+P;C];!8LKD60```<J@XQ!`+>D,P$W@^`^,Y8``H.,$\__K#WN?[0![
M@.T/>Y_M`GN`[0][G^T$>X#M#WN?[09[@.T/>Y_M`""@XPA[@.T.>Y_M>""`
MY0I[@.T,>X#M$("]Z`#P(.,!(T5G`````(FKS>\`````_MRZF`````!V5#(0
M`````/#ATL,````````````````!RJ#C\$<MZ0S`3>#@#XSE`G"@X0`PH.,!
M@*#A*!"0Y2P@D.6'P8'@`0!<X0(@T^``4*#A,""0Y300D.7'#Z#A`0``*@$@
MDN(`$*'B+#"%Y:<^H.&`,8/A`C"3X*`>H>!X`)7E*,"%Y0``4.,P,(7E-!"%
MY3A@A0(6```*0$!@XCA@A>('`%3A``"&X`=`H*$(`%#A0@``.@20B.`!``":
M"0!0X3D``#H($*#A!""@X2;S_^MX,)7E`S"$X$``4^-X,(7E\(>]&`4`H.&'
M_/_K"8"@X01P1^`_`%?C&P``V@A`H.%XD(7B0*"(X@0`5N$B```J"0!4X20`
M`#H*@*#A!C"@X4`@A.(`X)3E!,"4Y0@`E.4,$)3E$$"$X@(`5.$`X(/E!,"#
MY0@`@^4,$(/E$#"#XO/__QH%`*#A0'!'XFK\_^L_`%?C0*"*XN;__\H(`%;A
M#@``.@(``)H',(C@`P!6X0D``#H'(*#A"!"@X08`H.'U\O_K>'"%Y?"'O>@*
M@*#AW?__F@H`5N';__\J\`#PYP<PAN`#`%CA\?__*OK__^H$,(#@`P!8X020
MB""\__\J]?__Z@'*H./P02WI#,!-X.@/C.5_P.#C*#"1Y3!@D>4S?[_FHS&@
MX3\P`^(!((/B.("!XC@`4N,`4*#A`4"@X39OO^8#P,CG`@"(X#L``-H`$*#C
M0"!BXEKR_^L$`*#A-?S_ZS@@H.,`$*#C"`"@X53R_^L$`*#A\&?$X2[\_^L#
M,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%Y0`PE.4#,,7E"S#4Y00P
MQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4',,7E$S#4Y0@PQ>6R,=3A"3#%
MY1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A
M#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%Y2`PE.4C-*#A$C#%Y2`PE.43
M,,7E\$&]Z(?R_^H`$*#C."!BXA[R_^O(___J`4`MZ0%`O>@>_R_A/@```$$`
M```,````00```!$```!!````)P```$$````V````00````,```!!````!@``
M`$$````5````00````\```!!````#@```$$````F````00```!,```!!````
M*0```$$````"````00```!D```!!````"@```$$````+````00``````````
M````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-
M4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"
M`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!
M0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@``
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M`````#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%2
M65]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-
M10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'
M24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?
M<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P
M.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R
M7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@
M*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.
M3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@
M*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B
M=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY
M("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R
M;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@
M+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO
M9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I
M;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN
M+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD
M(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M
M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A
M<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L
M("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O
M;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S
M(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\
M(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-
M04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U
M=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B
M7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA
M<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD
M72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L
M(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F
M9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S
M=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?
M;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E
M('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO
M9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H
M)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I
M;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET[
M"GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_
M"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]
M?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ
M<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=
M.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B
M1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N
M=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T
M;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]
M*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I
M;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K
M("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N
M86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?
M<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E
M="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z
M:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY
M("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H
M95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S
M:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U
M9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*
M)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP
M;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I
M+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@
M:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`<&5R;'AS:2YC`````$-!0TA%```^````00````P```!!````$0```$$`
M```G````00```#8```!!`````P```$$````&````00```!4```!!````#P``
M`$$````.````00```"8```!!````$P```$$````I````00````(```!!````
M&0```$$````*````00````L```!!````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````P!<``"@7```!````%@,`
M``$````A`P``'0```'4$```,````6!````T```"T2```&0```,R=```;````
M!````!H```#0G0``'`````0```#U_O]O<`$```4```#\"```!@```%P"```*
M````DP0```L````0````%0`````````#````Q)X```(```#8`0``%````!$`
M```7````@`X``!$```"0#0``$@```/`````3````"````!X````(````^___
M;P$```CZ__]O$```````````````````````````````````````````````
M``````````#4G0````````````!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00
M``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!``
M`&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```
M9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```$`3`````````````+1(
M`````````````%@0````````````````````````````````````````````
M`````````````*````I005(N<&T*`````(A,``"<20```````%Q*``!@2@``
M?$P``*1)``"$3````````&A,``!P3````````)!,``!'0T,Z("A!;'!I;F4@
M,30N,BXP*2`Q-"XR+C``03(```!A96%B:0`!*`````4V2UH`!@<(`0D!"@(2
M!!,!%`$5`1<#&`$:`AP!'@(B`40!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN
M9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````
M```````````````````````````````````````+`````0````(````T`0``
M-`$``!@```````````````$`````````$P````<````"````3`$``$P!```D
M```````````````$`````````"8```#V__]O`@```'`!``!P`0``[`````0`
M````````!`````0````P````"P````(```!<`@``7`(``*`&```%`````P``
M``0````0````.`````,````"````_`@``/P(``"3!``````````````!````
M`````$`````)`````@```)`-``"0#0``\`````0`````````!`````@```!)
M````"0```$(```"`#@``@`X``-@!```$````$0````0````(````4@````$`
M```&````6!```%@0```,```````````````$`````````$T````!````!@``
M`&00``!D$```V`(`````````````!`````0```!8`````0````8```!`$P``
M0!,``'0U``````````````@`````````7@````$````&````M$@``+1(```,
M```````````````$`````````&0````!`````@```,!(``#`2```Y$$`````
M````````!`````````!L`````0````(```"DB@``I(H```0`````````````
M``0`````````=@````X````#````S)T``,R-```$```````````````$````
M!````((````/`````P```-"=``#0C0``!```````````````!`````0```".
M````!@````,```#4G0``U(T``/`````%``````````0````(````EP````$`
M```#````Q)X``,2.```\`0`````````````$````!````)P````!`````P``
M``"@````D```1```````````````!`````````"B````"`````,```!$H```
M1)```"P```````````````0`````````IP````$````P`````````$20```<
M```````````````!`````0```+`````#``!P``````````!@D```,P``````
M`````````0`````````!`````P``````````````DY```,``````````````
)``$`````````
